@@ -28,14 +28,12 @@
 
 #include <vorbis/vorbisfile.h>
 
-#include <libtracker-common/tracker-file-utils.h>
-
-#include <libtracker-client/tracker.h>
+#include <libtracker-common/tracker-common.h>
 
 #include <libtracker-extract/tracker-extract.h>
 
 typedef struct {
-	gchar *creator;
+	const gchar *creator;
 } MergeData;
 
 typedef struct {
@@ -106,7 +104,7 @@ extract_vorbis (const char *uri,
 	MergeData md = { 0 };
 	FILE *f;
 	gchar *filename;
-	OggVorbis_File  vf;
+	OggVorbis_File vf;
 	vorbis_comment *comment;
 	vorbis_info *vi;
 	unsigned int bitrate;
@@ -172,7 +170,7 @@ extract_vorbis (const char *uri,
 	md.creator = tracker_coalesce_strip (3, vd.artist, vd.album_artist, vd.performer);
 
 	if (md.creator) {
-		gchar *uri = tracker_uri_printf_escaped ("urn:artist:%s", md.creator);
+		gchar *uri = tracker_sparql_escape_uri_printf ("urn:artist:%s", md.creator);
 
 		tracker_sparql_builder_insert_open (preupdate, NULL);
 		tracker_sparql_builder_subject_iri (preupdate, uri);
@@ -181,7 +179,6 @@ extract_vorbis (const char *uri,
 		tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
 		tracker_sparql_builder_object_unvalidated (preupdate, md.creator);
 		tracker_sparql_builder_insert_close (preupdate);
-		g_free (md.creator);
 
 		tracker_sparql_builder_predicate (metadata, "nmm:performer");
 		tracker_sparql_builder_object_iri (metadata, uri);
@@ -189,7 +186,7 @@ extract_vorbis (const char *uri,
 	}
 
 	if (vd.album) {
-		gchar *uri = tracker_uri_printf_escaped ("urn:album:%s", vd.album);
+		gchar *uri = tracker_sparql_escape_uri_printf ("urn:album:%s", vd.album);
 
 		tracker_sparql_builder_insert_open (preupdate, NULL);
 		tracker_sparql_builder_subject_iri (preupdate, uri);
